==> easytag-2.1.8.tar.xz: easytag-2.1.8/src/ui_manager.h <==
/*
 * - bar.h : defines constant associated to the action "<menuitem action="
 * - bar.c : Create_UI() does the actions
 */

static const gchar *ui_xml =
"<ui>"

/*
 * Menu bar
 */
"  <menubar name='MenuBar'>"
"    <menu action='FileMenu'>"

"      <menu action='SortTagMenu'>"
"        <menuitem action='SortTrackNumAsc' />"
"        <menuitem action='SortTrackNumDesc' />"
"        <separator />"
"        <menuitem action='SortTitleAsc' />"
"        <menuitem action='SortTitleDesc' />"
"        <separator />"
"        <menuitem action='SortArtistAsc' />"
"        <menuitem action='SortArtistDesc' />"
"        <separator />"
"        <menuitem action='SortAlbumArtistAsc' />"
"        <menuitem action='SortAlbumArtistDesc' />"
"        <separator />"
"        <menuitem action='SortAlbumAsc' />"
"        <menuitem action='SortAlbumDesc' />"
"        <separator />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator />"
"        <menuitem action='SortGenreAsc' />"
"        <menuitem action='SortGenreDesc' />"
"        <separator />"
"        <menuitem action='SortCommentAsc' />"
"        <menuitem action='SortCommentDesc' />"
"        <separator />"
"        <menuitem action='SortComposerAsc' />"
"        <menuitem action='SortComposerDesc' />"
"        <separator />"
"        <menuitem action='SortOrigArtistAsc' />"
"        <menuitem action='SortOrigArtistDesc' />"
"        <separator />"
"        <menuitem action='SortCopyrightAsc' />"
"        <menuitem action='SortCopyrightDesc' />"
"        <separator />"
"        <menuitem action='SortUrlAsc' />"
"        <menuitem action='SortUrlDesc' />"
"        <separator />"
"        <menuitem action='SortEncodedByAsc' />"
"        <menuitem action='SortEncodedByDesc' />"
"        <separator />"
"      </menu>"

"      <menu action='SortPropMenu'>"
"        <menuitem action='SortFilenameAsc' />"
"        <menuitem action='SortFilenameDesc' />"
"        <separator />"
"        <menuitem action='SortDateAsc' />"
"        <menuitem action='SortDateDesc' />"
"        <separator />"
"        <menuitem action='SortTypeAsc' />"
"        <menuitem action='SortTypeDesc' />"
"        <separator />"
"        <menuitem action='SortSizeAsc' />"
"        <menuitem action='SortSizeDesc' />"
"        <separator />"
"        <menuitem action='SortDurationAsc' />"
"        <menuitem action='SortDurationDesc' />"
"        <separator />"
"        <menuitem action='SortBitrateAsc' />"
"        <menuitem action='SortBitrateDesc' />"
"        <separator />"
"        <menuitem action='SortSamplerateAsc' />"
"        <menuitem action='SortSamplerateDesc' />"
"      </menu>"

"      <menuitem action='OpenFile' />"
"      <separator />"

"      <menuitem action='SelAll' />"
"      <menuitem action='UnselAll' />"
"      <menuitem action='SelInv' />"
"      <separator />"

"      <menuitem action='DeleteFile' />"
"      <separator />"

"      <menuitem action='FirstFile' />"
"      <menuitem action='PreviousFile' />"
"      <menuitem action='NextFile' />"
"      <menuitem action='LastFile' />"
"      <separator />"

"      <menuitem action='ScanFile' />"
"      <menuitem action='RemoveTag' />"
"      <menuitem action='UndoFile' />"
"      <menuitem action='RedoFile' />"
"      <menuitem action='SaveFile' />"
"      <menuitem action='SaveFileForced' />"
"      <separator />"

"      <menuitem action='Undo' />"
"      <menuitem action='Redo' />"
"      <separator />"

"      <menuitem action='Quit' />"
"    </menu>"


"    <menu action='BrowserMenu'>"
"      <menuitem action='GoToHome' />"
"      <menuitem action='GoToDesktop' />"
"      <menuitem action='GoToDocument' />"
"      <menuitem action='GoToDownload' />"
"      <menuitem action='GoToMusic' />"
"      <separator />"
"      <menuitem action='GoToDefaultPath' />"
"      <menuitem action='SetDefaultPath' />"
"      <separator />"

"      <menuitem action='ViewMode' />"
"      <menuitem action='RenameDir' />"
"      <menuitem action='ReloadDir' />"
"      <menuitem action='BrowseDir' />"
"      <separator />"

"      <menuitem action='BrowseSubdir' />"
#ifndef G_OS_WIN32
"      <menuitem action='BrowseHiddenDir' />"
#endif /* !G_OS_WIN32 */
"      <separator />"

"      <menuitem action='CollapseTree' />"
"      <menuitem action='RefreshTree' />"
"    </menu>"

"    <menu action='ScannerMenu'>"
"      <menuitem action='FillTag' />"
"      <menuitem action='RenameFile' />"
"      <menuitem action='ProcessFields' />"
"    </menu>"

"    <menu action='MiscMenu'>"
"      <menuitem action='SearchFile' />"
"      <menuitem action='CDDBSearch' />"
"      <separator />"

"      <menuitem action='LoadFilenames' />"
"      <menuitem action='WritePlaylist' />"
"      <menuitem action='RunAudio' />"
"    </menu>"

"    <menu action='SettingsMenu'>"
"      <menuitem action='Preferences' />"
"    </menu>"

"    <menu action='HelpMenu'>"
"      <menuitem action='About' />"
"    </menu>"

"  </menubar>"


/*
 * Tool bar
 */
"  <toolbar name='ToolBar'>"
"    <toolitem action='FirstFile'/>"
"    <toolitem action='PreviousFile'/>"
"    <toolitem action='NextFile'/>"
"    <toolitem action='LastFile'/>"
"    <separator />"

"    <toolitem action='ScanFile'/>"
"    <toolitem action='RemoveTag'/>"
"    <toolitem action='UndoFile'/>"
"    <toolitem action='RedoFile'/>"
"    <toolitem action='SaveFile'/>"
"    <separator />"

"    <toolitem action='ViewModeToggle'/>"
"    <toolitem action='SelAll'/>"
"    <toolitem action='SelInv'/>"
"    <separator />"

"    <toolitem action='SearchFile' />"
"    <toolitem action='CDDBSearch' />"
"    <toolitem action='WritePlaylist' />"
"    <separator />"

"    <toolitem action='Stop'/>"
"    <separator />"

"    <toolitem action='Quit'/>"
"  </toolbar>"


/*
 * Popup menus
 */
// Popup in file list
"  <popup name='FilePopup'>"
"    <menuitem action='SelAll' />"
"    <menuitem action='UnselAll' />"
"    <menuitem action='SelInv' />"
"    <separator />"
"    <menuitem action='RunAudio' />"
"    <separator />"
"    <menu action='ScannerSubpopup'>"
"      <menuitem action='FillTag' />"
"      <menuitem action='RenameFile' />"
"      <menuitem action='ProcessFields' />"
"    </menu>"
"    <menuitem action='CDDBSearchFile' />"
"    <menuitem action='SearchFile' />"
"    <menuitem action='DeleteFile' />"
"    <menuitem action='ReloadDir' />"
"    <menuitem action='OpenFile' />"
"    <separator />"

"    <menu action='SortTagMenu'>"
"      <menuitem action='SortTrackNumAsc' />"
"      <menuitem action='SortTrackNumDesc' />"
"      <separator />"
"      <menuitem action='SortTitleAsc' />"
"      <menuitem action='SortTitleDesc' />"
"      <separator />"
"      <menuitem action='SortArtistAsc' />"
"      <menuitem action='SortArtistDesc' />"
"      <separator />"
"      <menuitem action='SortAlbumArtistAsc' />"
"      <menuitem action='SortAlbumArtistDesc' />"
"      <separator />"
"      <menuitem action='SortAlbumAsc' />"
"      <menuitem action='SortAlbumDesc' />"
"      <separator />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator />"
"      <menuitem action='SortGenreAsc' />"
"      <menuitem action='SortGenreDesc' />"
"      <separator />"
"      <menuitem action='SortCommentAsc' />"
"      <menuitem action='SortCommentDesc' />"
"      <separator />"
"      <menuitem action='SortComposerAsc' />"
"      <menuitem action='SortComposerDesc' />"
"      <separator />"
"      <menuitem action='SortOrigArtistAsc' />"
"      <menuitem action='SortOrigArtistDesc' />"
"      <separator />"
"      <menuitem action='SortCopyrightAsc' />"
"      <menuitem action='SortCopyrightDesc' />"
"      <separator />"
"      <menuitem action='SortUrlAsc' />"
"      <menuitem action='SortUrlDesc' />"
"      <separator />"
"      <menuitem action='SortEncodedByAsc' />"
"      <menuitem action='SortEncodedByDesc' />"
"      <separator />"
"    </menu>"

"    <menu action='SortPropMenu'>"
"      <menuitem action='SortFilenameAsc' />"
"      <menuitem action='SortFilenameDesc' />"
"      <separator />"
"      <menuitem action='SortDateAsc' />"
"      <menuitem action='SortDateDesc' />"
"      <separator />"
"      <menuitem action='SortTypeAsc' />"
"      <menuitem action='SortTypeDesc' />"
"      <separator />"
"      <menuitem action='SortSizeAsc' />"
"      <menuitem action='SortSizeDesc' />"
"      <separator />"
"      <menuitem action='SortDurationAsc' />"
"      <menuitem action='SortDurationDesc' />"
"      <separator />"
"      <menuitem action='SortBitrateAsc' />"
"      <menuitem action='SortBitrateDesc' />"
"      <separator />"
"      <menuitem action='SortSamplerateAsc' />"
"      <menuitem action='SortSamplerateDesc' />"
"    </menu>"
"  </popup>"

// Popup in browser tree
"  <popup name='DirPopup'>"
"    <menuitem action='DirPopupRunAudio' />"
"    <separator />"
"    <menuitem action='GoToHome' />"
"    <menuitem action='GoToDefaultPath' />"
"    <menuitem action='SetDefaultPath' />"
"    <separator />"
"    <menuitem action='RenameDir' />"
"    <menuitem action='ReloadDir' />"
"    <menuitem action='BrowseDir' />"
"    <separator />"
"    <menuitem action='BrowseSubdir' />"
#ifndef G_OS_WIN32
"    <menuitem action='BrowseHiddenDir' />"
#endif /* !G_OS_WIN32 */
"    <separator />"
"    <menuitem action='CollapseTree' />"
"    <menuitem action='RefreshTree' />"
"  </popup>"

// Popup in browser artist list
"  <popup name='DirArtistPopup'>"
"    <menuitem action='ArtistRunAudio' />"
//"    <separator />"
//"    <menuitem action='ArtistOpenFile' />"
"  </popup>"

// Popup in browser album list
"  <popup name='DirAlbumPopup'>"
"    <menuitem action='AlbumRunAudio' />"
//"    <separator />"
//"    <menuitem action='AlbumOpenFile' />"
"  </popup>"

// Popup in Log list
"  <popup name='LogPopup'>"
"    <menuitem action='CleanLog' />"
"  </popup>"

"</ui>";

==> easytag-2.2.0.tar.xz: easytag-2.2.0/src/ui_manager.h <==
/*
 * - bar.h : defines constant associated to the action "<menuitem action="
 * - bar.c : Create_UI() does the actions
 */

static const gchar *ui_xml =
"<ui>"

/*
 * Menu bar
 */
"  <menubar name='MenuBar'>"
"    <menu action='FileMenu'>"

"      <menuitem action='OpenFile' />"
"      <menuitem action='RunAudio' />"
"      <separator />"

"      <menuitem action='SelInv' />"
"      <separator />"

"      <menuitem action='DeleteFile' />"
"      <separator />"

"      <menuitem action='UndoFile' />"
"      <menuitem action='RedoFile' />"
"      <menuitem action='SaveFile' />"
"      <menuitem action='SaveFileForced' />"
"      <separator />"

"      <menuitem action='Quit' />"
"    </menu>"


"    <menu action='EditMenu'>"
"      <menuitem action='SearchFile' />"
"      <menuitem action='SelAll' />"
"      <menuitem action='UnselAll' />"
"      <separator />"

"      <menuitem action='Undo' />"
"      <menuitem action='Redo' />"
"      <separator />"

"      <menuitem action='RemoveTag' />"
"      <separator />"

"      <menuitem action='Preferences' />"
"    </menu>"

"    <menu action='ViewMenu'>"
"      <menuitem action='ShowScanner' />"
"      <menu action='ScannerMenu'>"
"        <menuitem action='FillTag' />"
"        <menuitem action='RenameFile' />"
"        <menuitem action='ProcessFields' />"
"      </menu>"
"      <separator />"

"      <menuitem action='TreeViewMode'/>"
"      <menuitem action='ArtistViewMode'/>"
"      <separator />"

"      <menu action='SortTagMenu'>"
"        <menuitem action='SortTrackNumAsc' />"
"        <menuitem action='SortTrackNumDesc' />"
"        <separator />"
"        <menuitem action='SortTitleAsc' />"
"        <menuitem action='SortTitleDesc' />"
"        <separator />"
"        <menuitem action='SortArtistAsc' />"
"        <menuitem action='SortArtistDesc' />"
"        <separator />"
"        <menuitem action='SortAlbumArtistAsc' />"
"        <menuitem action='SortAlbumArtistDesc' />"
"        <separator />"
"        <menuitem action='SortAlbumAsc' />"
"        <menuitem action='SortAlbumDesc' />"
"        <separator />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator />"
"        <menuitem action='SortGenreAsc' />"
"        <menuitem action='SortGenreDesc' />"
"        <separator />"
"        <menuitem action='SortCommentAsc' />"
"        <menuitem action='SortCommentDesc' />"
"        <separator />"
"        <menuitem action='SortComposerAsc' />"
"        <menuitem action='SortComposerDesc' />"
"        <separator />"
"        <menuitem action='SortOrigArtistAsc' />"
"        <menuitem action='SortOrigArtistDesc' />"
"        <separator />"
"        <menuitem action='SortCopyrightAsc' />"
"        <menuitem action='SortCopyrightDesc' />"
"        <separator />"
"        <menuitem action='SortUrlAsc' />"
"        <menuitem action='SortUrlDesc' />"
"        <separator />"
"        <menuitem action='SortEncodedByAsc' />"
"        <menuitem action='SortEncodedByDesc' />"
"      </menu>"

"      <menu action='SortPropMenu'>"
"        <menuitem action='SortFilenameAsc' />"
"        <menuitem action='SortFilenameDesc' />"
"        <separator />"
"        <menuitem action='SortDateAsc' />"
"        <menuitem action='SortDateDesc' />"
"        <separator />"
"        <menuitem action='SortTypeAsc' />"
"        <menuitem action='SortTypeDesc' />"
"        <separator />"
"        <menuitem action='SortSizeAsc' />"
"        <menuitem action='SortSizeDesc' />"
"        <separator />"
"        <menuitem action='SortDurationAsc' />"
"        <menuitem action='SortDurationDesc' />"
"        <separator />"
"        <menuitem action='SortBitrateAsc' />"
"        <menuitem action='SortBitrateDesc' />"
"        <separator />"
"        <menuitem action='SortSamplerateAsc' />"
"        <menuitem action='SortSamplerateDesc' />"
"      </menu>"
"      <separator />"

"      <menuitem action='CollapseTree' />"
"      <menuitem action='RefreshTree' />"
"      <separator />"

"      <menuitem action='ReloadDir' />"
"      <separator />"

#ifndef G_OS_WIN32
"      <menuitem action='BrowseHiddenDir' />"
#endif /* !G_OS_WIN32 */
"    </menu>"

"    <menu action='BrowserMenu'>"
"      <menuitem action='SetDefaultPath' />"
"      <separator />"

"      <menuitem action='RenameDir' />"
"      <menuitem action='BrowseDir' />"
"      <separator />"

"      <menuitem action='BrowseSubdir' />"
"    </menu>"

"    <menu action='MiscMenu'>"
"      <menuitem action='CDDBSearch' />"
"      <separator />"

"      <menuitem action='LoadFilenames' />"
"      <menuitem action='WritePlaylist' />"
"    </menu>"

"    <menu action='GoMenu'>"
"      <menuitem action='GoToHome' />"
"      <menuitem action='GoToDesktop' />"
"      <menuitem action='GoToDocument' />"
"      <menuitem action='GoToDownload' />"
"      <menuitem action='GoToMusic' />"
"      <menuitem action='GoToParent' />"
"      <menuitem action='GoToDefaultPath' />"
"      <separator />"

"      <menuitem action='FirstFile' />"
"      <menuitem action='PreviousFile' />"
"      <menuitem action='NextFile' />"
"      <menuitem action='LastFile' />"
"    </menu>"

"    <menu action='HelpMenu'>"
#ifndef G_OS_WIN32
"      <menuitem action='HelpContents' />"
#endif /* !G_OS_WIN32 */
"      <menuitem action='About' />"
"    </menu>"

"  </menubar>"


/*
 * Tool bar
 */
"  <toolbar name='ToolBar'>"
"    <toolitem action='FirstFile'/>"
"    <toolitem action='PreviousFile'/>"
"    <toolitem action='NextFile'/>"
"    <toolitem action='LastFile'/>"
"    <separator />"

"    <toolitem action='ShowScanner'/>"
"    <toolitem action='RemoveTag'/>"
"    <toolitem action='UndoFile'/>"
"    <toolitem action='RedoFile'/>"
"    <toolitem action='SaveFile'/>"
"    <separator />"

"    <toolitem action='TreeViewMode'/>"
"    <toolitem action='ArtistViewMode'/>"
"    <separator />"

"    <toolitem action='SelInv'/>"
"    <separator />"

"    <toolitem action='SearchFile' />"
"    <toolitem action='CDDBSearch' />"
"    <toolitem action='WritePlaylist' />"
"    <separator />"

"    <toolitem action='Stop'/>"
"  </toolbar>"


/*
 * Popup menus
 */
// Popup in file list
"  <popup name='FilePopup'>"
"    <menuitem action='SelAll' />"
"    <menuitem action='UnselAll' />"
"    <menuitem action='SelInv' />"
"    <separator />"
"    <menuitem action='RunAudio' />"
"    <separator />"
"    <menu action='ScannerSubpopup'>"
"      <menuitem action='ShowScanner' />"
"    </menu>"
"    <menuitem action='CDDBSearchFile' />"
"    <menuitem action='SearchFile' />"
"    <menuitem action='DeleteFile' />"
"    <menuitem action='ReloadDir' />"
"    <menuitem action='OpenFile' />"
"    <separator />"

"    <menu action='SortTagMenu'>"
"      <menuitem action='SortTrackNumAsc' />"
"      <menuitem action='SortTrackNumDesc' />"
"      <separator />"
"      <menuitem action='SortTitleAsc' />"
"      <menuitem action='SortTitleDesc' />"
"      <separator />"
"      <menuitem action='SortArtistAsc' />"
"      <menuitem action='SortArtistDesc' />"
"      <separator />"
"      <menuitem action='SortAlbumArtistAsc' />"
"      <menuitem action='SortAlbumArtistDesc' />"
"      <separator />"
"      <menuitem action='SortAlbumAsc' />"
"      <menuitem action='SortAlbumDesc' />"
"      <separator />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator />"
"      <menuitem action='SortGenreAsc' />"
"      <menuitem action='SortGenreDesc' />"
"      <separator />"
"      <menuitem action='SortCommentAsc' />"
"      <menuitem action='SortCommentDesc' />"
"      <separator />"
"      <menuitem action='SortComposerAsc' />"
"      <menuitem action='SortComposerDesc' />"
"      <separator />"
"      <menuitem action='SortOrigArtistAsc' />"
"      <menuitem action='SortOrigArtistDesc' />"
"      <separator />"
"      <menuitem action='SortCopyrightAsc' />"
"      <menuitem action='SortCopyrightDesc' />"
"      <separator />"
"      <menuitem action='SortUrlAsc' />"
"      <menuitem action='SortUrlDesc' />"
"      <separator />"
"      <menuitem action='SortEncodedByAsc' />"
"      <menuitem action='SortEncodedByDesc' />"
"      <separator />"
"    </menu>"

"    <menu action='SortPropMenu'>"
"      <menuitem action='SortFilenameAsc' />"
"      <menuitem action='SortFilenameDesc' />"
"      <separator />"
"      <menuitem action='SortDateAsc' />"
"      <menuitem action='SortDateDesc' />"
"      <separator />"
"      <menuitem action='SortTypeAsc' />"
"      <menuitem action='SortTypeDesc' />"
"      <separator />"
"      <menuitem action='SortSizeAsc' />"
"      <menuitem action='SortSizeDesc' />"
"      <separator />"
"      <menuitem action='SortDurationAsc' />"
"      <menuitem action='SortDurationDesc' />"
"      <separator />"
"      <menuitem action='SortBitrateAsc' />"
"      <menuitem action='SortBitrateDesc' />"
"      <separator />"
"      <menuitem action='SortSamplerateAsc' />"
"      <menuitem action='SortSamplerateDesc' />"
"    </menu>"
"  </popup>"

// Popup in browser tree
"  <popup name='DirPopup'>"
"    <menuitem action='DirPopupRunAudio' />"
"    <separator />"
"    <menuitem action='GoToHome' />"
"    <menuitem action='GoToDefaultPath' />"
"    <menuitem action='SetDefaultPath' />"
"    <separator />"
"    <menuitem action='RenameDir' />"
"    <menuitem action='ReloadDir' />"
"    <menuitem action='BrowseDir' />"
"    <separator />"
"    <menuitem action='BrowseSubdir' />"
#ifndef G_OS_WIN32
"    <menuitem action='BrowseHiddenDir' />"
#endif /* !G_OS_WIN32 */
"    <separator />"
"    <menuitem action='CollapseTree' />"
"    <menuitem action='RefreshTree' />"
"  </popup>"

// Popup in browser artist list
"  <popup name='DirArtistPopup'>"
"    <menuitem action='ArtistRunAudio' />"
//"    <separator />"
//"    <menuitem action='ArtistOpenFile' />"
"  </popup>"

// Popup in browser album list
"  <popup name='DirAlbumPopup'>"
"    <menuitem action='AlbumRunAudio' />"
//"    <separator />"
//"    <menuitem action='AlbumOpenFile' />"
"  </popup>"

// Popup in Log list
"  <popup name='LogPopup'>"
"    <menuitem action='CleanLog' />"
"  </popup>"

"</ui>";
